@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008-2012 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2013 Mario Kemper <mario.kemper@gmail.com>
 #
 #  This file is part of Shutter.
 #
@@ -48,7 +48,7 @@ sub new {
 	my $self = { _shutter_root => shift, _mainwindow => shift, _appname => shift, _version => shift, _rev => shift, _pid => shift };
 
 	#vars
-	$self->{_debug_cparam}              = FALSE;
+	$self->{_debug_cparam}              = TRUE;
 	$self->{_clear_cache}               = FALSE;
 	$self->{_min_cparam}                = FALSE;
 	$self->{_disable_systray_cparam}    = FALSE;
