@@ -25,7 +25,6 @@ package Shutter::Upload::Shared;
 
 use utf8;
 use strict;
-use warnings;
 use POSIX qw/setlocale/;
 use Locale::gettext;
 use Glib qw/TRUE FALSE/;
@@ -51,7 +50,8 @@ sub new {
 	$self->{_username} = undef;
 	$self->{_password} = undef;
 
-	$self->{_notebook} = Gtk3::Notebook->new;
+	$self->{_notebook} = Gtk2::Notebook->new;
+	$self->{_notebook}->set( homogeneous => 1 );
 	$self->{_notebook}->set_scrollable(TRUE);
 
 	bless $self, $class;
@@ -61,18 +61,18 @@ sub new {
 sub create_tab {
 	my $self = shift;
 
-	my $upload_vbox = Gtk3::VBox->new(FALSE, 0);
+	my $upload_vbox = Gtk2::VBox->new( FALSE, 0 );
 
 	#sizegroup for all labels
-	my $sg = Gtk3::SizeGroup->new('horizontal');
+	my $sg = Gtk2::SizeGroup->new('horizontal');
 
 	#create entry for each link
-	foreach (sort keys %{$self->{_links}}) {
+	foreach (sort keys %{$self->{_links}}){
 		next if $_ eq 'status';
 		my $box = $self->create_entry_for_notebook($_, $self->{_links}->{$_}, $sg);
 		$upload_vbox->pack_start($box, FALSE, FALSE, 3);
 	}
-
+	
 	return $upload_vbox;
 }
 
@@ -80,44 +80,48 @@ sub create_entry_for_notebook {
 	my ($self, $field, $value, $sg) = @_;
 
 	#Clipboard
-	my $clipboard = Gtk3::Clipboard::get($Gtk3::Gdk::SELECTION_CLIPBOARD);
-
-	my $upload_hbox1 = Gtk3::HBox->new(FALSE, 10);
-	my $upload_hbox2 = Gtk3::HBox->new(FALSE, 10);
+	my $clipboard = Gtk2::Clipboard->get( Gtk2::Gdk->SELECTION_CLIPBOARD );
 
+	#Tooltips
+	my $tooltips = Gtk2::Tooltips->new;
+	
+	my $upload_hbox1 = Gtk2::HBox->new(FALSE, 10);
+	my $upload_hbox2 = Gtk2::HBox->new(FALSE, 10);
+	
 	#prepare $field
 	$field =~ s/_/ /ig;
 	$field = ucfirst $field;
-	my $label = Gtk3::Label->new($field);
-	$label->set_alignment(0, 0.5);
+	my $label = Gtk2::Label->new($field);
+	$label->set_alignment( 0, 0.5 );
 	$sg->add_widget($label);
-
-	my $entry = Gtk3::Entry->new();
+	
+	my $entry = Gtk2::Entry->new();
 	$entry->set_text($value);
-	$entry->signal_connect(
-		'button-release-event' => sub {
+	$entry->signal_connect( 'button-release-event' => sub {
 			my ($widget, $event) = @_;
 			$widget->select_region(0, -1);
 			return FALSE;
-		});
-
-	my $upload_copy = Gtk3::Button->new;
-	$upload_copy->set_tooltip_text($self->{_gettext_object}->get("Copy this code to clipboard"));
-
-	$upload_copy->set_image(Gtk3::Image->new_from_stock('gtk-copy', 'menu'));
+		}
+	);
+	
+	my $upload_copy = Gtk2::Button->new;
+	$tooltips->set_tip( $upload_copy,
+		$self->{_gettext_object}->get("Copy this code to clipboard") );
+	
+	$upload_copy->set_image( Gtk2::Image->new_from_stock( 'gtk-copy', 'menu' ) );
 	$upload_copy->signal_connect(
 		'clicked' => sub {
-			my ($widget, $entry) = @_;
-			$clipboard->set_text($entry->get_text);
+			my ( $widget, $entry ) = @_;
+			$clipboard->set_text( $entry->get_text );
 		},
 		$entry
 	);
-
-	$upload_hbox1->pack_start($label,        FALSE, FALSE, 10);
-	$upload_hbox1->pack_start($entry,        TRUE,  TRUE,  3);
-	$upload_hbox2->pack_start($upload_hbox1, TRUE,  TRUE,  0);
-	$upload_hbox2->pack_start($upload_copy,  FALSE, TRUE,  3);
-
+	
+	$upload_hbox1->pack_start($label, FALSE, FALSE, 10);
+	$upload_hbox1->pack_start($entry, TRUE, TRUE, 3);
+	$upload_hbox2->pack_start($upload_hbox1, TRUE, TRUE, 0);
+	$upload_hbox2->pack_start($upload_copy, FALSE, TRUE, 3);
+	
 	return $upload_hbox2;
 }
 
@@ -128,14 +132,19 @@ sub show_all {
 	return FALSE if $self->{_notebook}->get_n_pages < 1;
 
 	my $dlg_header = sprintf($self->{_gettext_object}->get("Upload - %s - %s"), $self->{_host}, $self->{_username});
-	my $upload_dialog = Gtk3::Dialog->new($dlg_header, $self->{_main_gtk_window}, [qw/modal destroy-with-parent/], 'gtk-ok' => 'accept');
+	my $upload_dialog = Gtk2::Dialog->new(
+		$dlg_header,
+		$self->{_main_gtk_window},
+		[qw/modal destroy-with-parent/],
+		'gtk-ok' => 'accept'
+	);
 	$upload_dialog->set_default_response('accept');
 
-	$upload_dialog->get_child->add($self->{_notebook});
+	$upload_dialog->vbox->add( $self->{_notebook} );
 	$upload_dialog->show_all;
 	my $upload_response = $upload_dialog->run;
 
-	if ($upload_response eq "accept") {
+	if($upload_response eq "accept") {
 		$upload_dialog->destroy();
 		return TRUE;
 	} else {
@@ -147,13 +156,16 @@ sub show_all {
 sub show {
 	my $self = shift;
 
+	#Tooltips
+	my $tooltips = Gtk2::Tooltips->new;
+	
 	#Create label for each notebook page
-	my $fnlabel = Gtk3::Label->new($self->{_filename});
+	my $fnlabel = Gtk2::Label->new($self->{_filename});
 	$fnlabel->set_ellipsize('middle');
 	$fnlabel->set_width_chars(20);
-	$fnlabel->set_tooltip_text($self->{_filename});
+	$tooltips->set_tip( $fnlabel, $self->{_filename} );
 
-	$self->{_notebook}->append_page($self->create_tab(), $fnlabel);
+	$self->{_notebook}->append_page( $self->create_tab(), $fnlabel );
 
 	return TRUE;
 }
